Credits
=======

Development Lead
----------------

- TIA Lab <tialab@dcs.warwick.ac.uk>
- Shan E Ahmed Raza  <shaneahmed>
- John Pocock <John-P>
- Simon Graham <simongraham>
- Dang Vu <vqdang>

Contributors
------------

- Jev Gamper <jgamper>
- Srijay Deshpande <Srijay-lab>
- Saad Bashir <rajasaad>
